@@ -5,6 +5,8 @@ function( midsobj ){
 			}
     m <- midsobj$m
     datlist <- as.list( 1:m )
-    for (ii in 1:m){  datlist[[ii]] <- complete( midsobj , ii ) }
+    for (ii in 1:m){  
+			datlist[[ii]] <- complete( midsobj , ii ) 
+					}
     return(datlist)
         }
